@@ -1,7 +1,7 @@
 #
 # Monitorix - A lightweight system monitoring tool.
 #
-# Copyright (C) 2005-2020 by Jordi Sanfeliu <jordi@fibranet.cat>
+# Copyright (C) 2005-2022 by Jordi Sanfeliu <jordi@fibranet.cat>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -29,6 +29,8 @@ use File::Basename;
 use Exporter 'import';
 our @EXPORT = qw(disk_init disk_update disk_cgi);
 
+sub isnan { ! defined( $_[0] <=> (0+"inf")) }
+
 sub disk_init {
 	my $myself = (caller(0))[3];
 	my ($package, $config, $debug) = @_;
@@ -182,6 +184,8 @@ sub disk_update {
 	my ($package, $config, $debug) = @_;
 	my $rrd = $config->{base_lib} . $package . ".rrd";
 	my $disk = $config->{disk};
+	my $respect_standby = lc($disk->{respect_standby} || "") eq "y" ? 1 : 0;
+	my $use_nan_for_missing_data = lc($disk->{use_nan_for_missing_data} || "") eq "y" ? 1 : 0;
 
 	my $temp;
 	my $smart1;
@@ -194,9 +198,9 @@ sub disk_update {
 		# values delimitted by ", " (comma + space)
 		my @dsk = split(', ', $disk->{list}->{$k});
 		for($n = 0; $n < 8; $n++) {
-			$temp = 0;
-			$smart1 = 0;
-			$smart2 = 0;
+			$temp = $use_nan_for_missing_data ? (0+"nan") : 0;
+			$smart1 = $use_nan_for_missing_data ? (0+"nan") : 0;
+			$smart2 = $use_nan_for_missing_data ? (0+"nan") : 0;
 			if($dsk[$n]) {
 				my $d = trim($dsk[$n]);
 				$d =~ s/^\"//;
@@ -208,8 +212,12 @@ sub disk_update {
 					$d = abs_path(dirname($d) . "/" . readlink($d));
 					chomp($d);
 				}
+				my $smartctl_options = "-A";
+				if($respect_standby) {
+					$smartctl_options .= " -n standby";
+				}
 
-	  			open(IN, "smartctl -A $d |");
+				open(IN, "smartctl $smartctl_options $d |");
 				while(<IN>) {
 					if(/^  5/ && /Reallocated_Sector_Ct/) {
 						my @tmp = split(' ', $_);
@@ -223,7 +231,7 @@ sub disk_update {
 					}
 					if(/^190/ && /Airflow_Temperature_Cel/) {
 						my @tmp = split(' ', $_);
-						$temp = $tmp[9] unless $temp;
+						$temp = $tmp[9] unless ($temp && !isnan($temp));
 						chomp($temp);
 					}
 					if(/^197/ && /Current_Pending_Sector/) {
@@ -233,18 +241,18 @@ sub disk_update {
 					}
 					if(/^Current Drive Temperature: /) {
 						my @tmp = split(' ', $_);
-						$temp = $tmp[3] unless $temp;
+						$temp = $tmp[3] unless ($temp && !isnan($temp));
 						chomp($temp);
 					}
 					if(/^Temperature: /) {
-                                                my @tmp = split(' ', $_);
-                                                $temp = $tmp[1] unless $temp;
-                                                chomp($temp);
-                                        }
+						my @tmp = split(' ', $_);
+						$temp = $tmp[1] unless ($temp && !isnan($temp));
+						chomp($temp);
+					}
 				}
 				close(IN);
-				if(!$temp) {
-	  				if(open(IN, "hddtemp -wqn $d |")) {
+				if(!$temp && !$respect_standby) {
+					if(open(IN, "hddtemp -wqn $d |")) {
 						$temp = <IN>;
 						close(IN);
 					} else {
@@ -259,8 +267,7 @@ sub disk_update {
 
 			# DISK alert
 			if(lc($disk->{alerts}->{realloc_enabled}) eq "y") {
-				$config->{disk_hist_alert1}->{$n} = 0
-					if(!$config->{disk_hist_alert1}->{$n});
+				$config->{disk_hist_alert1}->{$n} = 0 if(!$config->{disk_hist_alert1}->{$n});
 				if($smart1 >= $disk->{alerts}->{realloc_threshold} && $config->{disk_hist_alert1}->{$n} < $smart1) {
 					if(-x $disk->{alerts}->{realloc_script}) {
 						logger("$myself: ALERT: executing script '$disk->{alerts}->{realloc_script}'.");
@@ -272,8 +279,7 @@ sub disk_update {
 				}
 			}
 			if(lc($disk->{alerts}->{pendsect_enabled}) eq "y") {
-				$config->{disk_hist_alert2}->{$n} = 0
-					if(!$config->{disk_hist_alert2}->{$n});
+				$config->{disk_hist_alert2}->{$n} = 0 if(!$config->{disk_hist_alert2}->{$n});
 				if($smart2 >= $disk->{alerts}->{pendsect_threshold} && $config->{disk_hist_alert2}->{$n} < $smart2) {
 					if(-x $disk->{alerts}->{pendsect_script}) {
 						logger("$myself: ALERT: executing script '$disk->{alerts}->{pendsect_script}'.");
@@ -310,6 +316,7 @@ sub disk_cgi {
 		'old' => \&RRDs::graph,
 	);
 	my $version = "new";
+	my @full_size_mode;
 	my $pic;
 	my $picz;
 	my $picz_width;
@@ -344,6 +351,7 @@ sub disk_cgi {
 	);
 
 	$version = "old" if $RRDs::VERSION < 1.3;
+	push(@full_size_mode, "--full-size-mode") if $RRDs::VERSION > 1.3;
 	my $rrd = $config->{base_lib} . $package . ".rrd";
 	my $title = $config->{graph_title}->{$package};
 	my $IMG_DIR = $config->{base_dir} . "/" . $config->{imgs_dir};
@@ -358,7 +366,7 @@ sub disk_cgi {
 	if(lc($config->{temperature_scale}) eq "f") {
 		$temp_scale = "Fahrenheit";
 	}
-
+	my $gap_on_all_nan = lc($disk->{gap_on_all_nan} || "") eq "y" ? 1 : 0;
 
 	# text mode
 	#
@@ -483,7 +491,7 @@ sub disk_cgi {
 					chomp($dstr);
 				}
 
-				$dstr =~ s/^(.+?) .*$/$1/;
+#				$dstr =~ s/^(.+?) .*$/$1/;
 				if($base && defined($disk->{map}->{$base})) {
 					$dstr = $disk->{map}->{$base};
 				} else {
@@ -542,6 +550,7 @@ sub disk_cgi {
 			push(@tmp, "COMMENT: \\n");
 			push(@tmp, "COMMENT: \\n");
 		}
+		my $cdef_allvalues_temp = $gap_on_all_nan ? "CDEF:allvalues=temp0,UN,0,1,IF,temp1,UN,0,1,IF,temp2,UN,0,1,IF,temp3,UN,0,1,IF,temp4,UN,0,1,IF,temp5,UN,0,1,IF,temp6,UN,0,1,IF,temp7,UN,0,1,IF,+,+,+,+,+,+,+,0,GT,1,UNKN,IF" : "CDEF:allvalues=temp0,temp1,temp2,temp3,temp4,temp5,temp6,temp7,+,+,+,+,+,+,+";
 		$pic = $rrd{$version}->("$IMG_DIR" . "$IMG[$e * 3]",
 			"--title=$config->{graphs}->{_disk1}  ($tf->{nwhen}$tf->{twhen})",
 			"--start=-$tf->{nwhen}$tf->{twhen}",
@@ -562,7 +571,7 @@ sub disk_cgi {
 			"DEF:temp5=$rrd:disk" . $e ."_hd5_temp:AVERAGE",
 			"DEF:temp6=$rrd:disk" . $e ."_hd6_temp:AVERAGE",
 			"DEF:temp7=$rrd:disk" . $e ."_hd7_temp:AVERAGE",
-			"CDEF:allvalues=temp0,temp1,temp2,temp3,temp4,temp5,temp6,temp7,+,+,+,+,+,+,+",
+			$cdef_allvalues_temp,
 			@CDEF,
 			@tmp);
 		$err = RRDs::error;
@@ -576,6 +585,7 @@ sub disk_cgi {
 				"--vertical-label=$temp_scale",
 				"--width=$width",
 				"--height=$height",
+				@full_size_mode,
 				@extra,
 				@riglim,
 				$zoom,
@@ -589,7 +599,7 @@ sub disk_cgi {
 				"DEF:temp5=$rrd:disk" . $e ."_hd5_temp:AVERAGE",
 				"DEF:temp6=$rrd:disk" . $e ."_hd6_temp:AVERAGE",
 				"DEF:temp7=$rrd:disk" . $e ."_hd7_temp:AVERAGE",
-				"CDEF:allvalues=temp0,temp1,temp2,temp3,temp4,temp5,temp6,temp7,+,+,+,+,+,+,+",
+				$cdef_allvalues_temp,
 				@CDEF,
 				@tmpz);
 			$err = RRDs::error;
@@ -599,7 +609,7 @@ sub disk_cgi {
 		if($title || ($silent =~ /imagetag/ && $graph =~ /disk$e2/)) {
 			if(lc($config->{enable_zoom}) eq "y") {
 				if(lc($config->{disable_javascript_void}) eq "y") {
-					push(@output, "      <a href=\"" . $config->{url} . "/" . $config->{imgs_dir} . $IMGz[$e * 3] . "\"><img src='" . $config->{url} . "/" . $config->{imgs_dir} . $IMG[$e * 3] . "' border='0'></a>\n");
+					push(@output, "      " . picz_a_element(config => $config, IMGz => $IMGz[$e * 3], IMG => $IMG[$e * 3]) . "\n");
 				} else {
 					if($version eq "new") {
 						$picz_width = $picz->{image_width} * $config->{global_zoom};
@@ -608,10 +618,10 @@ sub disk_cgi {
 						$picz_width = $width + 115;
 						$picz_height = $height + 100;
 					}
-					push(@output, "      <a href=\"javascript:void(window.open('" . $config->{url} . "/" . $config->{imgs_dir} . $IMGz[$e * 3] . "','','width=" . $picz_width . ",height=" . $picz_height . ",scrollbars=0,resizable=0'))\"><img src='" . $config->{url} . "/" . $config->{imgs_dir} . $IMG[$e * 3] . "' border='0'></a>\n");
+					push(@output, "      " . picz_js_a_element(width => $picz_width, height => $picz_height, config => $config, IMGz => $IMGz[$e * 3], IMG => $IMG[$e * 3]) . "\n");
 				}
 			} else {
-				push(@output, "      <img src='" . $config->{url} . "/" . $config->{imgs_dir} . $IMG[$e * 3] . "'>\n");
+				push(@output, "      " . img_element(config => $config, IMG => $IMG[$e * 3]) . "\n");
 			}
 		}
 
@@ -626,34 +636,52 @@ sub disk_cgi {
 		for($n = 0; $n < 8; $n += 2) {
 			if($d[$n]) {
 				my $dstr = trim($d[$n]);
+				my $base = "";
 				$dstr =~ s/^\"//;
 				$dstr =~ s/\"$//;
 
 				# check if device name is a symbolic link
 				# e.g. /dev/disk/by-path/pci-0000:07:07.0-scsi-0:0:0:0
 				if(-l $dstr) {
+					$base = basename($dstr);
 					$dstr = abs_path(dirname($dstr) . "/" . readlink($dstr));
 					chomp($dstr);
 				}
 
-				$dstr =~ s/^(.+?) .*$/$1/;
+#				$dstr =~ s/^(.+?) .*$/$1/;
+				if($base && defined($disk->{map}->{$base})) {
+					$dstr = $disk->{map}->{$base};
+				} else {
+					if(defined($disk->{map}->{$dstr})) {
+						$dstr = $disk->{map}->{$dstr};
+					}
+				}
 				$str = sprintf("%-17s", substr($dstr, 0, 17));
 				push(@tmp, "LINE2:rsc" . $n . $LC[$n] . ":$str");
 				push(@tmpz, "LINE2:rsc" . $n . $LC[$n] . ":$dstr\\g");
 			}
 			if($d[$n + 1]) {
 				my $dstr = trim($d[$n + 1]);
+				my $base = "";
 				$dstr =~ s/^\"//;
 				$dstr =~ s/\"$//;
 
 				# check if device name is a symbolic link
 				# e.g. /dev/disk/by-path/pci-0000:07:07.0-scsi-0:0:0:0
 				if(-l $dstr) {
+					$base = basename($dstr);
 					$dstr = abs_path(dirname($dstr) . "/" . readlink($dstr));
 					chomp($dstr);
 				}
 
-				$dstr =~ s/^(.+?) .*$/$1/;
+#				$dstr =~ s/^(.+?) .*$/$1/;
+				if($base && defined($disk->{map}->{$base})) {
+					$dstr = $disk->{map}->{$base};
+				} else {
+					if(defined($disk->{map}->{$dstr})) {
+						$dstr = $disk->{map}->{$dstr};
+					}
+				}
 				$str = sprintf("%-17s", substr($dstr, 0, 17));
 				push(@tmp, "LINE2:rsc" . ($n + 1) . $LC[$n + 1] . ":$str\\n");
 				push(@tmpz, "LINE2:rsc" . ($n + 1) . $LC[$n + 1] . ":$dstr\\g");
@@ -673,6 +701,7 @@ sub disk_cgi {
 			push(@tmp, "COMMENT: \\n");
 			push(@tmp, "COMMENT: \\n");
 		}
+		my $cdef_allvalues_rsc = $gap_on_all_nan ? "CDEF:allvalues=rsc0,UN,0,1,IF,rsc1,UN,0,1,IF,rsc2,UN,0,1,IF,rsc3,UN,0,1,IF,rsc4,UN,0,1,IF,rsc5,UN,0,1,IF,rsc6,UN,0,1,IF,rsc7,UN,0,1,IF,+,+,+,+,+,+,+,0,GT,1,UNKN,IF" : "CDEF:allvalues=rsc0,rsc1,rsc2,rsc3,rsc4,rsc5,rsc6,rsc7,+,+,+,+,+,+,+";
 		$pic = $rrd{$version}->("$IMG_DIR" . "$IMG[$e * 3 + 1]",
 			"--title=$config->{graphs}->{_disk2}  ($tf->{nwhen}$tf->{twhen})",
 			"--start=-$tf->{nwhen}$tf->{twhen}",
@@ -694,7 +723,7 @@ sub disk_cgi {
 			"DEF:rsc5=$rrd:disk" . $e . "_hd5_smart1:AVERAGE",
 			"DEF:rsc6=$rrd:disk" . $e . "_hd6_smart1:AVERAGE",
 			"DEF:rsc7=$rrd:disk" . $e . "_hd7_smart1:AVERAGE",
-			"CDEF:allvalues=rsc0,rsc1,rsc2,rsc3,rsc4,rsc5,rsc6,rsc7,+,+,+,+,+,+,+",
+			$cdef_allvalues_rsc,
 			@CDEF,
 			@tmp);
 		$err = RRDs::error;
@@ -708,6 +737,7 @@ sub disk_cgi {
 				"--vertical-label=Sectors",
 				"--width=$width",
 				"--height=$height",
+				@full_size_mode,
 				@extra,
 				@riglim,
 				$zoom,
@@ -722,7 +752,7 @@ sub disk_cgi {
 				"DEF:rsc5=$rrd:disk" . $e . "_hd5_smart1:AVERAGE",
 				"DEF:rsc6=$rrd:disk" . $e . "_hd6_smart1:AVERAGE",
 				"DEF:rsc7=$rrd:disk" . $e . "_hd7_smart1:AVERAGE",
-				"CDEF:allvalues=rsc0,rsc1,rsc2,rsc3,rsc4,rsc5,rsc6,rsc7,+,+,+,+,+,+,+",
+				$cdef_allvalues_rsc,
 				@CDEF,
 				@tmpz);
 			$err = RRDs::error;
@@ -732,7 +762,7 @@ sub disk_cgi {
 		if($title || ($silent =~ /imagetag/ && $graph =~ /disk$e2/)) {
 			if(lc($config->{enable_zoom}) eq "y") {
 				if(lc($config->{disable_javascript_void}) eq "y") {
-					push(@output, "      <a href=\"" . $config->{url} . "/" . $config->{imgs_dir} . $IMGz[$e * 3 + 1] . "\"><img src='" . $config->{url} . "/" . $config->{imgs_dir} . $IMG[$e * 3 + 1] . "' border='0'></a>\n");
+					push(@output, "      " . picz_a_element(config => $config, IMGz => $IMGz[$e * 3 + 1], IMG => $IMG[$e * 3 + 1]) . "\n");
 				} else {
 					if($version eq "new") {
 						$picz_width = $picz->{image_width} * $config->{global_zoom};
@@ -741,10 +771,10 @@ sub disk_cgi {
 						$picz_width = $width + 115;
 						$picz_height = $height + 100;
 					}
-					push(@output, "      <a href=\"javascript:void(window.open('" . $config->{url} . "/" . $config->{imgs_dir} . $IMGz[$e * 3 + 1] . "','','width=" . $picz_width . ",height=" . $picz_height . ",scrollbars=0,resizable=0'))\"><img src='" . $config->{url} . "/" . $config->{imgs_dir} . $IMG[$e * 3 + 1] . "' border='0'></a>\n");
+					push(@output, "      " . picz_js_a_element(width => $picz_width, height => $picz_height, config => $config, IMGz => $IMGz[$e * 3 + 1], IMG => $IMG[$e * 3 + 1]) . "\n");
 				}
 			} else {
-				push(@output, "      <img src='" . $config->{url} . "/" . $config->{imgs_dir} . $IMG[$e * 3 + 1] . "'>\n");
+				push(@output, "      " . img_element(config => $config, IMG => $IMG[$e * 3 + 1]) . "\n");
 			}
 		}
 
@@ -755,34 +785,52 @@ sub disk_cgi {
 		for($n = 0; $n < 8; $n += 2) {
 			if($d[$n]) {
 				my $dstr = trim($d[$n]);
+				my $base = "";
 				$dstr =~ s/^\"//;
 				$dstr =~ s/\"$//;
 
 				# check if device name is a symbolic link
 				# e.g. /dev/disk/by-path/pci-0000:07:07.0-scsi-0:0:0:0
 				if(-l $dstr) {
+					$base = basename($dstr);
 					$dstr = abs_path(dirname($dstr) . "/" . readlink($dstr));
 					chomp($dstr);
 				}
 
-				$dstr =~ s/^(.+?) .*$/$1/;
+#				$dstr =~ s/^(.+?) .*$/$1/;
+				if($base && defined($disk->{map}->{$base})) {
+					$dstr = $disk->{map}->{$base};
+				} else {
+					if(defined($disk->{map}->{$dstr})) {
+						$dstr = $disk->{map}->{$dstr};
+					}
+				}
 				$str = sprintf("%-17s", substr($dstr, 0, 17));
 				push(@tmp, "LINE2:cps" . $n . $LC[$n] . ":$str");
 				push(@tmpz, "LINE2:cps" . $n . $LC[$n] . ":$dstr\\g");
 			}
 			if($d[$n + 1]) {
 				my $dstr = trim($d[$n + 1]);
+				my $base = "";
 				$dstr =~ s/^\"//;
 				$dstr =~ s/\"$//;
 
 				# check if device name is a symbolic link
 				# e.g. /dev/disk/by-path/pci-0000:07:07.0-scsi-0:0:0:0
 				if(-l $dstr) {
+					$base = basename($dstr);
 					$dstr = abs_path(dirname($dstr) . "/" . readlink($dstr));
 					chomp($dstr);
 				}
 
-				$dstr =~ s/^(.+?) .*$/$1/;
+#				$dstr =~ s/^(.+?) .*$/$1/;
+				if($base && defined($disk->{map}->{$base})) {
+					$dstr = $disk->{map}->{$base};
+				} else {
+					if(defined($disk->{map}->{$dstr})) {
+						$dstr = $disk->{map}->{$dstr};
+					}
+				}
 				$str = sprintf("%-17s", substr($dstr, 0, 17));
 				push(@tmp, "LINE2:cps" . ($n + 1) . $LC[$n + 1] . ":$str\\n");
 				push(@tmpz, "LINE2:cps" . ($n + 1) . $LC[$n + 1] . ":$dstr\\g");
@@ -802,6 +850,7 @@ sub disk_cgi {
 			push(@tmp, "COMMENT: \\n");
 			push(@tmp, "COMMENT: \\n");
 		}
+		my $cdef_allvalues_cps = $gap_on_all_nan ? "CDEF:allvalues=cps0,UN,0,1,IF,cps1,UN,0,1,IF,cps2,UN,0,1,IF,cps3,UN,0,1,IF,cps4,UN,0,1,IF,cps5,UN,0,1,IF,cps6,UN,0,1,IF,cps7,UN,0,1,IF,+,+,+,+,+,+,+,0,GT,1,UNKN,IF" : "CDEF:allvalues=cps0,cps1,cps2,cps3,cps4,cps5,cps6,cps7,+,+,+,+,+,+,+";
 		$pic = $rrd{$version}->("$IMG_DIR" . "$IMG[$e * 3 + 2]",
 			"--title=$config->{graphs}->{_disk3}  ($tf->{nwhen}$tf->{twhen})",
 			"--start=-$tf->{nwhen}$tf->{twhen}",
@@ -823,7 +872,7 @@ sub disk_cgi {
 			"DEF:cps5=$rrd:disk" . $e . "_hd5_smart2:AVERAGE",
 			"DEF:cps6=$rrd:disk" . $e . "_hd6_smart2:AVERAGE",
 			"DEF:cps7=$rrd:disk" . $e . "_hd7_smart2:AVERAGE",
-			"CDEF:allvalues=cps0,cps1,cps2,cps3,cps4,cps5,cps6,cps7,+,+,+,+,+,+,+",
+			$cdef_allvalues_cps,
 			@CDEF,
 			@tmp);
 		$err = RRDs::error;
@@ -837,6 +886,7 @@ sub disk_cgi {
 				"--vertical-label=Sectors",
 				"--width=$width",
 				"--height=$height",
+				@full_size_mode,
 				@extra,
 				@riglim,
 				$zoom,
@@ -851,7 +901,7 @@ sub disk_cgi {
 				"DEF:cps5=$rrd:disk" . $e . "_hd5_smart2:AVERAGE",
 				"DEF:cps6=$rrd:disk" . $e . "_hd6_smart2:AVERAGE",
 				"DEF:cps7=$rrd:disk" . $e . "_hd7_smart2:AVERAGE",
-				"CDEF:allvalues=cps0,cps1,cps2,cps3,cps4,cps5,cps6,cps7,+,+,+,+,+,+,+",
+				$cdef_allvalues_cps,
 				@CDEF,
 				@tmpz);
 			$err = RRDs::error;
@@ -861,7 +911,7 @@ sub disk_cgi {
 		if($title || ($silent =~ /imagetag/ && $graph =~ /disk$e2/)) {
 			if(lc($config->{enable_zoom}) eq "y") {
 				if(lc($config->{disable_javascript_void}) eq "y") {
-					push(@output, "      <a href=\"" . $config->{url} . "/" . $config->{imgs_dir} . $IMGz[$e * 3 + 2] . "\"><img src='" . $config->{url} . "/" . $config->{imgs_dir} . $IMG[$e * 3 + 2] . "' border='0'></a>\n");
+					push(@output, "      " . picz_a_element(config => $config, IMGz => $IMGz[$e * 3 + 2], IMG => $IMG[$e * 3 + 2]) . "\n");
 				} else {
 					if($version eq "new") {
 						$picz_width = $picz->{image_width} * $config->{global_zoom};
@@ -870,10 +920,10 @@ sub disk_cgi {
 						$picz_width = $width + 115;
 						$picz_height = $height + 100;
 					}
-					push(@output, "      <a href=\"javascript:void(window.open('" . $config->{url} . "/" . $config->{imgs_dir} . $IMGz[$e * 3 + 2] . "','','width=" . $picz_width . ",height=" . $picz_height . ",scrollbars=0,resizable=0'))\"><img src='" . $config->{url} . "/" . $config->{imgs_dir} . $IMG[$e * 3 + 2] . "' border='0'></a>\n");
+					push(@output, "      " . picz_js_a_element(width => $picz_width, height => $picz_height, config => $config, IMGz => $IMGz[$e * 3 + 2], IMG => $IMG[$e * 3 + 2]) . "\n");
 				}
 			} else {
-				push(@output, "      <img src='" . $config->{url} . "/" . $config->{imgs_dir} . $IMG[$e * 3 + 2] . "'>\n");
+				push(@output, "      " . img_element(config => $config, IMG => $IMG[$e * 3 + 2]) . "\n");
 			}
 		}
 
