@@ -1,7 +1,7 @@
 #
 # Monitorix - A lightweight system monitoring tool.
 #
-# Copyright (C) 2005-2020 by Jordi Sanfeliu <jordi@fibranet.cat>
+# Copyright (C) 2005-2022 by Jordi Sanfeliu <jordi@fibranet.cat>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -37,6 +37,8 @@ sub du_init {
 	my $info;
 	my @ds;
 	my @rra;
+	my @ds_to_change_heartbeat;
+	my $rrd_heartbeat;
 	my @tmp;
 	my $n;
 
@@ -45,6 +47,12 @@ sub du_init {
 	my @max;
 	my @last;
 
+	my $heartbeat = 120;
+	my $refresh_interval = ($config->{du}->{refresh_interval} || 0);
+	if($refresh_interval > 0) {
+		$heartbeat = 2 * $refresh_interval;
+	}
+
 	if(-e $rrd) {
 		$info = RRDs::info($rrd);
 		for my $key (keys %$info) {
@@ -58,6 +66,15 @@ sub du_init {
 					push(@rra, substr($key, 4, index($key, ']') - 4));
 				}
 			}
+			if(index($key, 'ds[') == 0) {
+				if(index($key, '.minimal_heartbeat') != -1) {
+					$rrd_heartbeat = $info->{$key};
+					if($rrd_heartbeat != $heartbeat) {
+						my $ds_name = substr($key, 3, index($key, ']') - 3);
+						push(@ds_to_change_heartbeat, $ds_name);
+					}
+				}
+			}
 		}
 		if(scalar(@ds) / 9 != scalar(my @fl = split(',', $du->{list}))) {
 			logger("$myself: Detected size mismatch between 'list' (" . scalar(my @fl = split(',', $du->{list})) . ") and $rrd (" . scalar(@ds) / 9 . "). Resizing it accordingly. All historical data will be lost. Backup file created.");
@@ -67,6 +84,18 @@ sub du_init {
 			logger("$myself: Detected size mismatch between 'max_historic_years' (" . $config->{max_historic_years} . ") and $rrd (" . ((scalar(@rra) -12) / 4) . "). Resizing it accordingly. All historical data will be lost. Backup file created.");
 			rename($rrd, "$rrd.bak");
 		}
+		if((-e $rrd) && scalar(@ds_to_change_heartbeat) > 0) {
+			logger("$myself: Detected heartbeat mismatch between set (" . $heartbeat . ") and $rrd (" . $rrd_heartbeat . "). Tuning it accordingly.");
+			my @tune_arguments;
+			foreach(@ds_to_change_heartbeat) {
+				push(@tune_arguments, "-h");
+				push(@tune_arguments, "$_:$heartbeat");
+			}
+
+			RRDs::tune($rrd, @tune_arguments);
+			my $err = RRDs::error;
+			logger("ERROR: while tuning $rrd: $err") if $err;
+		}
 	}
 
 	if(!(-e $rrd)) {
@@ -78,15 +107,15 @@ sub du_init {
 			push(@last, "RRA:LAST:0.5:1440:" . (365 * $n));
 		}
 		for($n = 0; $n < scalar(my @fl = split(',', $du->{list})); $n++) {
-			push(@tmp, "DS:du" . $n . "_d1:GAUGE:120:0:U");
-			push(@tmp, "DS:du" . $n . "_d2:GAUGE:120:0:U");
-			push(@tmp, "DS:du" . $n . "_d3:GAUGE:120:0:U");
-			push(@tmp, "DS:du" . $n . "_d4:GAUGE:120:0:U");
-			push(@tmp, "DS:du" . $n . "_d5:GAUGE:120:0:U");
-			push(@tmp, "DS:du" . $n . "_d6:GAUGE:120:0:U");
-			push(@tmp, "DS:du" . $n . "_d7:GAUGE:120:0:U");
-			push(@tmp, "DS:du" . $n . "_d8:GAUGE:120:0:U");
-			push(@tmp, "DS:du" . $n . "_d9:GAUGE:120:0:U");
+			push(@tmp, "DS:du" . $n . "_d1:GAUGE:" . $heartbeat . ":0:U");
+			push(@tmp, "DS:du" . $n . "_d2:GAUGE:" . $heartbeat . ":0:U");
+			push(@tmp, "DS:du" . $n . "_d3:GAUGE:" . $heartbeat . ":0:U");
+			push(@tmp, "DS:du" . $n . "_d4:GAUGE:" . $heartbeat . ":0:U");
+			push(@tmp, "DS:du" . $n . "_d5:GAUGE:" . $heartbeat . ":0:U");
+			push(@tmp, "DS:du" . $n . "_d6:GAUGE:" . $heartbeat . ":0:U");
+			push(@tmp, "DS:du" . $n . "_d7:GAUGE:" . $heartbeat . ":0:U");
+			push(@tmp, "DS:du" . $n . "_d8:GAUGE:" . $heartbeat . ":0:U");
+			push(@tmp, "DS:du" . $n . "_d9:GAUGE:" . $heartbeat . ":0:U");
 		}
 		eval {
 			RRDs::create($rrd,
@@ -140,6 +169,14 @@ sub du_update {
 	my $str;
 	my $rrdata = "N";
 
+	my $refresh_interval = ($config->{du}->{refresh_interval} || 0);
+	if($refresh_interval > 60) {
+		# If desired refreshed only every refresh_interval seconds.
+		# This logic will refresh atleast once a day.
+		my (undef, $min, $hour) = localtime(time);
+		return if(($min + 60 * $hour) % int($refresh_interval / 60));
+	}
+
 	my $e = 0;
 	while($e < scalar(my @dl = split(',', $du->{list}))) {
 		my $type;
@@ -209,6 +246,7 @@ sub du_cgi {
 		'old' => \&RRDs::graph,
 	);
 	my $version = "new";
+	my @full_size_mode;
 	my $pic;
 	my $picz;
 	my $picz_width;
@@ -242,6 +280,7 @@ sub du_cgi {
 	my $type_label;
 
 	$version = "old" if $RRDs::VERSION < 1.3;
+	push(@full_size_mode, "--full-size-mode") if $RRDs::VERSION > 1.3;
 	my $rrd = $config->{base_lib} . $package . ".rrd";
 	my $title = $config->{graph_title}->{$package};
 	my $IMG_DIR = $config->{base_dir} . "/" . $config->{imgs_dir};
@@ -459,6 +498,7 @@ sub du_cgi {
 					"--vertical-label=$type_label",
 					"--width=$width",
 					"--height=$height",
+					@full_size_mode,
 					@extra,
 					@riglim,
 					$zoom,
@@ -474,7 +514,7 @@ sub du_cgi {
 			if($title || ($silent =~ /imagetag/ && $graph =~ /du$n/)) {
 				if(lc($config->{enable_zoom}) eq "y") {
 					if(lc($config->{disable_javascript_void}) eq "y") {
-						push(@output, "      <a href=\"" . $config->{url} . "/" . $config->{imgs_dir} . $IMGz[$n] . "\"><img src='" . $config->{url} . "/" . $config->{imgs_dir} . $IMG[$n] . "' border='0'></a>\n");
+						push(@output, "      " . picz_a_element(config => $config, IMGz => $IMGz[$n], IMG => $IMG[$n]) . "\n");
 					} else {
 						if($version eq "new") {
 							$picz_width = $picz->{image_width} * $config->{global_zoom};
@@ -483,10 +523,10 @@ sub du_cgi {
 							$picz_width = $width + 115;
 							$picz_height = $height + 100;
 						}
-						push(@output, "      <a href=\"javascript:void(window.open('" . $config->{url} . "/" . $config->{imgs_dir} . $IMGz[$n] . "','','width=" . $picz_width . ",height=" . $picz_height . ",scrollbars=0,resizable=0'))\"><img src='" . $config->{url} . "/" . $config->{imgs_dir} . $IMG[$n] . "' border='0'></a>\n");
+						push(@output, "      " . picz_js_a_element(width => $picz_width, height => $picz_height, config => $config, IMGz => $IMGz[$n], IMG => $IMG[$n]) . "\n");
 					}
 				} else {
-					push(@output, "      <img src='" . $config->{url} . "/" . $config->{imgs_dir} . $IMG[$n] . "'>\n");
+					push(@output, "      " . img_element(config => $config, IMG => $IMG[$n]) . "\n");
 				}
 			}
 			if($title) {
