@@ -1,7 +1,7 @@
 #
 # Monitorix - A lightweight system monitoring tool.
 #
-# Copyright (C) 2005-2020 by Jordi Sanfeliu <jordi@fibranet.cat>
+# Copyright (C) 2005-2022 by Jordi Sanfeliu <jordi@fibranet.cat>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -153,9 +153,7 @@ sub gensens_update {
 					$val = <IN>;
 					$val = trim($val);
 					$unit = $gensens->{unit}->{$str} || 0;
-					$c = () = $unit =~ /0/g;
-					$val /= 10**$c if $unit > 1;
-					$val *= 10**$c if $unit > 0 && $unit < 1;
+					$val /= $unit if $unit != 0;
 					close(IN);
 				} else {
 					logger("$myself: ERROR: unable to open '$gensens->{desc}->{$str}'.");
@@ -265,6 +263,7 @@ sub gensens_cgi {
 		'old' => \&RRDs::graph,
 	);
 	my $version = "new";
+	my @full_size_mode;
 	my $pic;
 	my $picz;
 	my $picz_width;
@@ -298,6 +297,7 @@ sub gensens_cgi {
 	);
 
 	$version = "old" if $RRDs::VERSION < 1.3;
+	push(@full_size_mode, "--full-size-mode") if $RRDs::VERSION > 1.3;
 	my $rrd = $config->{base_lib} . $package . ".rrd";
 	my $title = $config->{graph_title}->{$package};
 	my $IMG_DIR = $config->{base_dir} . "/" . $config->{imgs_dir};
@@ -424,13 +424,21 @@ sub gensens_cgi {
 	foreach my $sg (sort keys %{$gensens->{list}}) {
 		my @ls = split(',', $gensens->{list}->{$sg});
 
-		# determine if we are dealing with a 'temp', 'cpu' or 'bat' graph
+		# determine if we are dealing with a 'temp', 'cpu', 'bat', 'pwr', 'fan', 'pct' or 'byt' graph
 		if(index($ls[0], "temp") == 0) {
 			$vlabel = $temp_scale;
 		} elsif(index($ls[0], "cpu") == 0) {
 			$vlabel = "Hz";
 		} elsif(index($ls[0], "bat") == 0) {
 			$vlabel = "Charge";
+		} elsif(index($ls[0], "pwr") == 0) {
+			$vlabel = "Watt";
+		} elsif(index($ls[0], "fan") == 0) {
+			$vlabel = "RPM";
+		} elsif(index($ls[0], "pct") == 0) {
+			$vlabel = "Percent (%)";
+		} elsif(index($ls[0], "byt") == 0) {
+			$vlabel = "bytes";
 		} else {
 			# not supported yet
 		}
@@ -542,6 +550,7 @@ sub gensens_cgi {
 				"--vertical-label=$vlabel",
 				"--width=$width",
 				"--height=$height",
+				@full_size_mode,
 				@extra,
 				@riglim,
 				$zoom,
@@ -565,7 +574,7 @@ sub gensens_cgi {
 		if($title || ($silent =~ /imagetag/ && $graph =~ /gensens0/)) {
 			if(lc($config->{enable_zoom}) eq "y") {
 				if(lc($config->{disable_javascript_void}) eq "y") {
-					push(@output, "      <a href=\"" . $config->{url} . "/" . $config->{imgs_dir} . $IMGz[$e] . "\"><img src='" . $config->{url} . "/" . $config->{imgs_dir} . $IMG[$e] . "' border='0'></a>\n");
+					push(@output, "      " . picz_a_element(config => $config, IMGz => $IMGz[$e], IMG => $IMG[$e]) . "\n");
 				} else {
 					if($version eq "new") {
 						$picz_width = $picz->{image_width} * $config->{global_zoom};
@@ -574,10 +583,10 @@ sub gensens_cgi {
 						$picz_width = $width + 115;
 						$picz_height = $height + 100;
 					}
-					push(@output, "      <a href=\"javascript:void(window.open('" . $config->{url} . "/" . $config->{imgs_dir} . $IMGz[$e] . "','','width=" . $picz_width . ",height=" . $picz_height . ",scrollbars=0,resizable=0'))\"><img src='" . $config->{url} . "/" . $config->{imgs_dir} . $IMG[$e] . "' border='0'></a>\n");
+					push(@output, "      " . picz_js_a_element(width => $picz_width, height => $picz_height, config => $config, IMGz => $IMGz[$e], IMG => $IMG[$e]) . "\n");
 				}
 			} else {
-				push(@output, "      <img src='" . $config->{url} . "/" . $config->{imgs_dir} . $IMG[$e] . "'>\n");
+				push(@output, "      " . img_element(config => $config, IMG => $IMG[$e]) . "\n");
 			}
 		}
 
