@@ -1,7 +1,7 @@
 #
 # Monitorix - A lightweight system monitoring tool.
 #
-# Copyright (C) 2005-2020 by Jordi Sanfeliu <jordi@fibranet.cat>
+# Copyright (C) 2005-2022 by Jordi Sanfeliu <jordi@fibranet.cat>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -134,6 +134,7 @@ sub ipmi_update {
 	my $rrd = $config->{base_lib} . $package . ".rrd";
 	my $ipmi = $config->{ipmi};
 	my $args = $ipmi->{extra_args} || "";
+	my $use_nan_for_missing_data = lc($ipmi->{use_nan_for_missing_data} || "") eq "y" ? 1 : 0;
 
 	my @sens;
 
@@ -153,8 +154,7 @@ sub ipmi_update {
 		my $e2 = 0;
 		foreach my $i (split(',', $ipmi->{desc}->{$e})) {
 			my $unit;
-
-			$sens[$e][$e2] = 0 unless defined $sens[$e][$e2];
+			$sens[$e][$e2] = ($use_nan_for_missing_data ? (0+"nan") : 0) unless defined $sens[$e][$e2];
 			$str = trim($i);
 			$unit = $ipmi->{units}->{$e};
 			foreach(@data) {
@@ -169,7 +169,7 @@ sub ipmi_update {
 						my $timeintvl = trim($al[0]);
 						my $threshold = trim($al[1]);
 						my $script = trim($al[2]);
-			
+
 						if(!$threshold || $val < $threshold) {
 							$config->{ipmi_hist_alerts}->{$str} = 0;
 						} else {
@@ -214,6 +214,7 @@ sub ipmi_cgi {
 	my @output;
 
 	my $ipmi = $config->{ipmi};
+	my $gap_on_all_nan = lc($ipmi->{gap_on_all_nan} || "") eq "y" ? 1 : 0;
 	my @rigid = split(',', ($ipmi->{rigid} || ""));
 	my @limit = split(',', ($ipmi->{limit} || ""));
 	my $tf = $cgi->{tf};
@@ -226,6 +227,7 @@ sub ipmi_cgi {
 		'old' => \&RRDs::graph,
 	);
 	my $version = "new";
+	my @full_size_mode;
 	my $pic;
 	my $picz;
 	my $picz_width;
@@ -258,6 +260,7 @@ sub ipmi_cgi {
 	);
 
 	$version = "old" if $RRDs::VERSION < 1.3;
+	push(@full_size_mode, "--full-size-mode") if $RRDs::VERSION > 1.3;
 	my $rrd = $config->{base_lib} . $package . ".rrd";
 	my $title = $config->{graph_title}->{$package};
 	my $IMG_DIR = $config->{base_dir} . "/" . $config->{imgs_dir};
@@ -361,7 +364,6 @@ sub ipmi_cgi {
 		}
 	}
 
-	@riglim = @{setup_riglim($rigid[0], $limit[0])};
 	$n = 0;
 	while($n < scalar(my @sl = split(',', $ipmi->{list}))) {
 		if($title) {
@@ -375,6 +377,7 @@ sub ipmi_cgi {
 			if($title) {
 				push(@output, "    <td>\n");
 			}
+			@riglim = @{setup_riglim($rigid[$n], $limit[$n])};
 			undef(@tmp);
 			undef(@tmpz);
 			undef(@CDEF);
@@ -400,6 +403,7 @@ sub ipmi_cgi {
 			}
 			($width, $height) = split('x', $config->{graph_size}->{medium});
 			$str = substr(trim($sl[$n]), 0, 25);
+			my $cdef_allvalues = $gap_on_all_nan ? "CDEF:allvalues=s1,UN,0,1,IF,s2,UN,0,1,IF,s3,UN,0,1,IF,s4,UN,0,1,IF,s5,UN,0,1,IF,s6,UN,0,1,IF,s7,UN,0,1,IF,s8,UN,0,1,IF,s9,UN,0,1,IF,+,+,+,+,+,+,+,+,0,GT,1,UNKN,IF" : "CDEF:allvalues=s1,s2,s3,s4,s5,s6,s7,s8,s9,+,+,+,+,+,+,+,+";
 			$pic = $rrd{$version}->("$IMG_DIR" . "$IMG[$n]",
 				"--title=$str  ($tf->{nwhen}$tf->{twhen})",
 				"--start=-$tf->{nwhen}$tf->{twhen}",
@@ -421,7 +425,7 @@ sub ipmi_cgi {
 				"DEF:s7=$rrd:ipmi" . $n . "_s7:AVERAGE",
 				"DEF:s8=$rrd:ipmi" . $n . "_s8:AVERAGE",
 				"DEF:s9=$rrd:ipmi" . $n . "_s9:AVERAGE",
-				"CDEF:allvalues=s1,s2,s3,s4,s5,s6,s7,s8,s9,+,+,+,+,+,+,+,+",
+				$cdef_allvalues,
 				@CDEF,
 				@tmp);
 			$err = RRDs::error;
@@ -435,6 +439,7 @@ sub ipmi_cgi {
 					"--vertical-label=$unit",
 					"--width=$width",
 					"--height=$height",
+					@full_size_mode,
 					@extra,
 					@riglim,
 					$zoom,
@@ -449,7 +454,7 @@ sub ipmi_cgi {
 					"DEF:s7=$rrd:ipmi" . $n . "_s7:AVERAGE",
 					"DEF:s8=$rrd:ipmi" . $n . "_s8:AVERAGE",
 					"DEF:s9=$rrd:ipmi" . $n . "_s9:AVERAGE",
-					"CDEF:allvalues=s1,s2,s3,s4,s5,s6,s7,s8,s9,+,+,+,+,+,+,+,+",
+					$cdef_allvalues,
 					@CDEF,
 					@tmpz);
 				$err = RRDs::error;
@@ -458,7 +463,7 @@ sub ipmi_cgi {
 			if($title || ($silent =~ /imagetag/ && $graph =~ /ipmi$n/)) {
 				if(lc($config->{enable_zoom}) eq "y") {
 					if(lc($config->{disable_javascript_void}) eq "y") {
-						push(@output, "      <a href=\"" . $config->{url} . "/" . $config->{imgs_dir} . $IMGz[$n] . "\"><img src='" . $config->{url} . "/" . $config->{imgs_dir} . $IMG[$n] . "' border='0'></a>\n");
+						push(@output, "      " . picz_a_element(config => $config, IMGz => $IMGz[$n], IMG => $IMG[$n]) . "\n");
 					} else {
 						if($version eq "new") {
 							$picz_width = $picz->{image_width} * $config->{global_zoom};
@@ -467,10 +472,10 @@ sub ipmi_cgi {
 							$picz_width = $width + 115;
 							$picz_height = $height + 100;
 						}
-						push(@output, "      <a href=\"javascript:void(window.open('" . $config->{url} . "/" . $config->{imgs_dir} . $IMGz[$n] . "','','width=" . $picz_width . ",height=" . $picz_height . ",scrollbars=0,resizable=0'))\"><img src='" . $config->{url} . "/" . $config->{imgs_dir} . $IMG[$n] . "' border='0'></a>\n");
+						push(@output, "      " . picz_js_a_element(width => $picz_width, height => $picz_height, config => $config, IMGz => $IMGz[$n], IMG => $IMG[$n]) . "\n");
 					}
 				} else {
-					push(@output, "      <img src='" . $config->{url} . "/" . $config->{imgs_dir} . $IMG[$n] . "'>\n");
+					push(@output, "      " . img_element(config => $config, IMG => $IMG[$n]) . "\n");
 				}
 			}
 			if($title) {
