@@ -1,7 +1,7 @@
 #
 # Monitorix - A lightweight system monitoring tool.
 #
-# Copyright (C) 2005-2020 by Jordi Sanfeliu <jordi@fibranet.cat>
+# Copyright (C) 2005-2022 by Jordi Sanfeliu <jordi@fibranet.cat>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -343,6 +343,7 @@ sub port_cgi {
 		'old' => \&RRDs::graph,
 	);
 	my $version = "new";
+	my @full_size_mode;
 	my $pic;
 	my $picz;
 	my $picz_width;
@@ -369,6 +370,7 @@ sub port_cgi {
 	my $err;
 
 	$version = "old" if $RRDs::VERSION < 1.3;
+	push(@full_size_mode, "--full-size-mode") if $RRDs::VERSION > 1.3;
 	my $rrd = $config->{base_lib} . $package . ".rrd";
 	my $title = $config->{graph_title}->{$package};
 	my $IMG_DIR = $config->{base_dir} . "/" . $config->{imgs_dir};
@@ -539,30 +541,19 @@ sub port_cgi {
 			if(uc($plis || "") eq "L") {
 				if($config->{os} eq "Linux") {
 					my $cmd = $port->{cmd} || "";
-					if(!$cmd || $cmd eq "ss") {
-						open(IN, "ss -nl --$pp |");
-						while(<IN>) {
-							(undef, undef, undef, $pnum) = split(' ', $_);
-							chomp($pnum);
-							$pnum =~ s/.*://;
-							if($pnum eq $num) {
-								last;
-							}
-						}
-						close(IN);
+					if(!$cmd) {
+						$cmd = "ss";
 					}
-					if($cmd eq "netstat") {
-						open(IN, "netstat -nl --$pp |");
-						while(<IN>) {
-							(undef, undef, undef, $pnum) = split(' ', $_);
-							chomp($pnum);
-							$pnum =~ s/.*://;
-							if($pnum eq $num) {
-								last;
-							}
+					open(IN, "$cmd -nl --$pp |");
+					while(<IN>) {
+						(undef, undef, undef, $pnum) = split(' ', $_);
+						chomp($pnum);
+						$pnum =~ s/.*://;
+						if($pnum eq $num) {
+							last;
 						}
-						close(IN);
 					}
+					close(IN);
 				}
 				if(grep {$_ eq $config->{os}} ("FreeBSD", "OpenBSD")) {
 					open(IN, "netstat -anl -p $pp |");
@@ -694,6 +685,7 @@ sub port_cgi {
 					"--vertical-label=$vlabel",
 					"--width=$width",
 					"--height=$height",
+					@full_size_mode,
 					@extra,
 					@riglim,
 					$zoom,
@@ -714,7 +706,7 @@ sub port_cgi {
 			if($title || ($silent =~ /imagetag/ && $graph =~ /port$n3/)) {
 				if(lc($config->{enable_zoom}) eq "y") {
 					if(lc($config->{disable_javascript_void}) eq "y") {
-						push(@output, "      <a href=\"" . $config->{url} . "/" . $config->{imgs_dir} . $IMGz[$n3] . "\"><img src='" . $config->{url} . "/" . $config->{imgs_dir} . $IMG[$n3] . "' border='0'></a>\n");
+						push(@output, "      " . picz_a_element(config => $config, IMGz => $IMGz[$n3], IMG => $IMG[$n3]) . "\n");
 					} else {
 						if($version eq "new") {
 							$picz_width = $picz->{image_width} * $config->{global_zoom};
@@ -723,10 +715,10 @@ sub port_cgi {
 							$picz_width = $width + 115;
 							$picz_height = $height + 100;
 						}
-						push(@output, "      <a href=\"javascript:void(window.open('" . $config->{url} . "/" . $config->{imgs_dir} . $IMGz[$n3] . "','','width=" . $picz_width . ",height=" . $picz_height . ",scrollbars=0,resizable=0'))\"><img src='" . $config->{url} . "/" . $config->{imgs_dir} . $IMG[$n3] . "' border='0'></a>\n");
+						push(@output, "      " . picz_js_a_element(width => $picz_width, height => $picz_height, config => $config, IMGz => $IMGz[$n3], IMG => $IMG[$n3]) . "\n");
 					}
 				} else {
-					push(@output, "      <img src='" . $config->{url} . "/" . $config->{imgs_dir} . $IMG[$n3] . "'>\n");
+					push(@output, "      " . img_element(config => $config, IMG => $IMG[$n3]) . "\n");
 				}
 			}
 			if($title) {
