@@ -1,7 +1,7 @@
 #
 # Monitorix - A lightweight system monitoring tool.
 #
-# Copyright (C) 2005-2020 by Jordi Sanfeliu <jordi@fibranet.cat>
+# Copyright (C) 2005-2022 by Jordi Sanfeliu <jordi@fibranet.cat>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -94,7 +94,7 @@ sub process_init {
 				push(@tmp, "DS:proc" . $n . "_nth" . $n2 . ":GAUGE:120:0:U");
 				push(@tmp, "DS:proc" . $n . "_vcs" . $n2 . ":GAUGE:120:0:U");
 				push(@tmp, "DS:proc" . $n . "_ics" . $n2 . ":GAUGE:120:0:U");
-				push(@tmp, "DS:proc" . $n . "_va1" . $n2 . ":GAUGE:120:0:U");
+				push(@tmp, "DS:proc" . $n . "_upt" . $n2 . ":GAUGE:120:0:U");
 				push(@tmp, "DS:proc" . $n . "_va2" . $n2 . ":GAUGE:120:0:U");
 			}
 		}
@@ -133,6 +133,16 @@ sub process_init {
 		}
 	}
 
+	# Since 3.14.0 the process' uptime is now included in statistics
+	for($n = 0; $n < keys(%{$process->{list}}); $n++) {
+		my $n2;
+		for($n2 = 0; $n2 < 10; $n2++) {
+			RRDs::tune($rrd,
+			"--data-source-rename=proc" . $n . "_va1" . $n2 . ":proc" . $n . "_upt" . $n2
+			);
+		}
+	}
+
 	$config->{process_hist} = ();
 	push(@{$config->{func_update}}, $package);
 	logger("$myself: Ok") if $debug;
@@ -146,6 +156,8 @@ sub process_update {
 
 	my $n;
 	my $rrdata = "N";
+	my $ticks = `getconf CLK_TCK`;
+	my ($sysuptime) = split(' ', `cat /proc/uptime`);
 
 	my $e = 0;
 	foreach my $pg (sort keys %{$process->{list}}) {
@@ -160,6 +172,7 @@ sub process_update {
 			my $nth = 0;
 			my $vcs = 0;
 			my $ics = 0;
+			my $upt = 0;
 
 			my $str;
 			my @pids;
@@ -169,6 +182,8 @@ sub process_update {
 
 			# check if that process is running
 			if(open(IN, "ps -eo pid,comm,command |")) {
+				my $pidwidth = length(`cat /proc/sys/kernel/pid_max`);
+
 				while(<IN>) {
 					if(m/^\s*(\d+)\s+(\S+)\s+(.*?)$/) {
 						if($p eq trim($2)) {
@@ -187,7 +202,7 @@ sub process_update {
 							next;
 						}
 					}
-					if(substr($p, 0, 15) eq substr($_, 6, 15)) {
+					if(substr($p, 0, 15) eq substr($_, $pidwidth, 15)) {
 						push(@pids, $1);
 						$pro++;
 						next;
@@ -213,6 +228,7 @@ sub process_update {
 					my $utime = 0;
 					my $stime = 0;
 					my $v_nth = 0;
+					my $starttime = 0;
 					my $v_mem = 0;
 					my $rest;
 
@@ -221,10 +237,13 @@ sub process_update {
 					(undef, $rest) = <IN> =~ m/^(\d+\s\(.*?\)\s\S\s)(.*?)$/;
 					close(IN);
 					if($rest) {
-						(undef, undef, undef, undef, undef, undef, undef, undef, undef, undef, $utime, $stime, undef, undef, undef, undef, $v_nth, undef, undef, undef, $v_mem) = split(' ', $rest);
+						(undef, undef, undef, undef, undef, undef, undef, undef, undef, undef, $utime, $stime, undef, undef, undef, undef, $v_nth, undef, $starttime, undef, $v_mem) = split(' ', $rest);
 						$mem += ($v_mem *= 4096);
 						$nth += ($v_nth - 1);
 						$p_usage += $utime + $stime;
+						$starttime /= $ticks;
+						my $diff = $sysuptime - $starttime;
+						$upt = $diff unless $diff < $upt;
 					} else {
 						logger("$myself: WARNING: PID $pid ('$p') has vanished while accounting!");
 					}
@@ -298,7 +317,7 @@ sub process_update {
 			$ics /= 60;
 			$config->{process_hist}->{$str} = $v_ics;
 
-			$rrdata .= ":$cpu:$mem:$dsk:$net:$nof:$pro:$nth:$vcs:$ics:0:0";
+			$rrdata .= ":$cpu:$mem:$dsk:$net:$nof:$pro:$nth:$vcs:$ics:$upt:0";
 		}
 		$e++;
 	}
@@ -326,6 +345,7 @@ sub process_cgi {
 		'old' => \&RRDs::graph,
 	);
 	my $version = "new";
+	my @full_size_mode;
 	my $pic;
 	my $picz;
 	my $picz_width;
@@ -364,6 +384,7 @@ sub process_cgi {
 	);
 
 	$version = "old" if $RRDs::VERSION < 1.3;
+	push(@full_size_mode, "--full-size-mode") if $RRDs::VERSION > 1.3;
 	my $rrd = $config->{base_lib} . $package . ".rrd";
 	my $title = $config->{graph_title}->{$package};
 	my $IMG_DIR = $config->{base_dir} . "/" . $config->{imgs_dir};
@@ -403,11 +424,11 @@ sub process_cgi {
 			my @lp = split(',', $process->{list}->{$pg});
 			for($n = 0; $n < scalar(@lp); $n++) {
 				my $p = trim($lp[$n]);
-				$str = sprintf("  %61s", trim((split(',', $process->{desc}->{$p} || $p))));
+				$str = sprintf("  %69s", trim((split(',', $process->{desc}->{$p} || $p))));
 				$line1 .= $str;
-				$str = sprintf("   CPU%%  Memory    Disk     Net  OFiles  NProcs Threads CtxtS/s");
+				$str = sprintf("   CPU%%  Memory    Disk     Net  OFiles  NProcs Threads CtxtS/s  Uptime");
 				$line2 .= $str;
-				$line3 .=      "---------------------------------------------------------------";
+				$line3 .=      "-----------------------------------------------------------------------";
 			}
 		}
 		push(@output, "     $line1\n");
@@ -429,7 +450,7 @@ sub process_cgi {
 				for($n2 = 0; $n2 < scalar(@lp); $n2++) {
 					$from = ($e * 10 * 11) + ($n2 * 11);
 					$to = $from + 11;
-					my ($cpu, $mem, $dsk, $net, $nof, $pro, $nth, $vcs, $ics) = @$line[$from..$to];
+					my ($cpu, $mem, $dsk, $net, $nof, $pro, $nth, $vcs, $ics, $upt) = @$line[$from..$to];
 					if(lc($config->{netstats_in_bps}) eq "y") {
 						$net *= 8;
 					}
@@ -441,7 +462,8 @@ sub process_cgi {
 					$pro ||= 0;
 					$nth ||= 0;
 					my $cs = ($vcs || 0) + ($ics || 0) ;
-					push(@output, sprintf("  %4.1f%% %6dM %6dM %6dM %7d %7d %7d %7d", $cpu, $mem, $dsk, $net, $nof, $pro, $nth, $cs));
+					$upt ||= 0;
+					push(@output, sprintf("  %4.1f%% %6dM %6dM %6dM %7d %7d %7d %7d %8d", $cpu, $mem, $dsk, $net, $nof, $pro, $nth, $cs, $upt));
 				}
 				$e++;
 			}
@@ -562,6 +584,7 @@ sub process_cgi {
 				"--vertical-label=Percent (%)",
 				"--width=$width",
 				"--height=$height",
+				@full_size_mode,
 				@extra,
 				@riglim,
 				$zoom,
@@ -587,7 +610,7 @@ sub process_cgi {
 		if($title || ($silent =~ /imagetag/ && $graph =~ /process$e2/)) {
 			if(lc($config->{enable_zoom}) eq "y") {
 				if(lc($config->{disable_javascript_void}) eq "y") {
-					push(@output, "      <a href=\"" . $config->{url} . "/" . $config->{imgs_dir} . $IMGz[$e * 10] . "\"><img src='" . $config->{url} . "/" . $config->{imgs_dir} . $IMG[$e * 10] . "' border='0'></a>\n");
+					push(@output, "      " . picz_a_element(config => $config, IMGz => $IMGz[$e * 10], IMG => $IMG[$e * 10]) . "\n");
 				} else {
 					if($version eq "new") {
 						$picz_width = $picz->{image_width} * $config->{global_zoom};
@@ -596,10 +619,10 @@ sub process_cgi {
 						$picz_width = $width + 115;
 						$picz_height = $height + 100;
 					}
-					push(@output, "      <a href=\"javascript:void(window.open('" . $config->{url} . "/" . $config->{imgs_dir} . $IMGz[$e * 10] . "','','width=" . $picz_width . ",height=" . $picz_height . ",scrollbars=0,resizable=0'))\"><img src='" . $config->{url} . "/" . $config->{imgs_dir} . $IMG[$e * 10] . "' border='0'></a>\n");
+					push(@output, "      " . picz_js_a_element(width => $picz_width, height => $picz_height, config => $config, IMGz => $IMGz[$e * 10], IMG => $IMG[$e * 10]) . "\n");
 				}
 			} else {
-				push(@output, "      <img src='" . $config->{url} . "/" . $config->{imgs_dir} . $IMG[$e * 10] . "'>\n");
+				push(@output, "      " . img_element(config => $config, IMG => $IMG[$e * 10]) . "\n");
 			}
 		}
 
@@ -685,6 +708,7 @@ sub process_cgi {
 				"--vertical-label=bytes",
 				"--width=$width",
 				"--height=$height",
+				@full_size_mode,
 				@extra,
 				@riglim,
 				$zoom,
@@ -720,7 +744,7 @@ sub process_cgi {
 		if($title || ($silent =~ /imagetag/ && $graph =~ /process$e2/)) {
 			if(lc($config->{enable_zoom}) eq "y") {
 				if(lc($config->{disable_javascript_void}) eq "y") {
-					push(@output, "      <a href=\"" . $config->{url} . "/" . $config->{imgs_dir} . $IMGz[$e * 10 + 1] . "\"><img src='" . $config->{url} . "/" . $config->{imgs_dir} . $IMG[$e * 10 + 1] . "' border='0'></a>\n");
+					push(@output, "      " . picz_a_element(config => $config, IMGz => $IMGz[$e * 10 + 1], IMG => $IMG[$e * 10 + 1]) . "\n");
 				} else {
 					if($version eq "new") {
 						$picz_width = $picz->{image_width} * $config->{global_zoom};
@@ -729,10 +753,10 @@ sub process_cgi {
 						$picz_width = $width + 115;
 						$picz_height = $height + 100;
 					}
-					push(@output, "      <a href=\"javascript:void(window.open('" . $config->{url} . "/" . $config->{imgs_dir} . $IMGz[$e * 10 + 1] . "','','width=" . $picz_width . ",height=" . $picz_height . ",scrollbars=0,resizable=0'))\"><img src='" . $config->{url} . "/" . $config->{imgs_dir} . $IMG[$e * 10 + 1] . "' border='0'></a>\n");
+					push(@output, "      " . picz_js_a_element(width => $picz_width, height => $picz_height, config => $config, IMGz => $IMGz[$e * 10 + 1], IMG => $IMG[$e * 10 + 1]) . "\n");
 				}
 			} else {
-				push(@output, "      <img src='" . $config->{url} . "/" . $config->{imgs_dir} . $IMG[$e * 10 + 1] . "'>\n");
+				push(@output, "      " . img_element(config => $config, IMG => $IMG[$e * 10 + 1]) . "\n");
 			}
 		}
 
@@ -815,6 +839,7 @@ sub process_cgi {
 				"--vertical-label=bytes/s",
 				"--width=$width",
 				"--height=$height",
+				@full_size_mode,
 				@extra,
 				@riglim,
 				$zoom,
@@ -850,7 +875,7 @@ sub process_cgi {
 		if($title || ($silent =~ /imagetag/ && $graph =~ /process$e2/)) {
 			if(lc($config->{enable_zoom}) eq "y") {
 				if(lc($config->{disable_javascript_void}) eq "y") {
-					push(@output, "      <a href=\"" . $config->{url} . "/" . $config->{imgs_dir} . $IMGz[$e * 10 + 2] . "\"><img src='" . $config->{url} . "/" . $config->{imgs_dir} . $IMG[$e * 10 + 2] . "' border='0'></a>\n");
+					push(@output, "      " . picz_a_element(config => $config, IMGz => $IMGz[$e * 10 + 2], IMG => $IMG[$e * 10 + 2]) . "\n");
 				} else {
 					if($version eq "new") {
 						$picz_width = $picz->{image_width} * $config->{global_zoom};
@@ -859,10 +884,10 @@ sub process_cgi {
 						$picz_width = $width + 115;
 						$picz_height = $height + 100;
 					}
-					push(@output, "      <a href=\"javascript:void(window.open('" . $config->{url} . "/" . $config->{imgs_dir} . $IMGz[$e * 10 + 2] . "','','width=" . $picz_width . ",height=" . $picz_height . ",scrollbars=0,resizable=0'))\"><img src='" . $config->{url} . "/" . $config->{imgs_dir} . $IMG[$e * 10 + 2] . "' border='0'></a>\n");
+					push(@output, "      " . picz_js_a_element(width => $picz_width, height => $picz_height, config => $config, IMGz => $IMGz[$e * 10 + 2], IMG => $IMG[$e * 10 + 2]) . "\n");
 				}
 			} else {
-				push(@output, "      <img src='" . $config->{url} . "/" . $config->{imgs_dir} . $IMG[$e * 10 + 2] . "'>\n");
+				push(@output, "      " . img_element(config => $config, IMG => $IMG[$e * 10 + 2]) . "\n");
 			}
 		}
 
@@ -961,6 +986,7 @@ sub process_cgi {
 				"--vertical-label=$vlabel",
 				"--width=$width",
 				"--height=$height",
+				@full_size_mode,
 				@extra,
 				@riglim,
 				$zoom,
@@ -986,7 +1012,7 @@ sub process_cgi {
 		if($title || ($silent =~ /imagetag/ && $graph =~ /process$e2/)) {
 			if(lc($config->{enable_zoom}) eq "y") {
 				if(lc($config->{disable_javascript_void}) eq "y") {
-					push(@output, "      <a href=\"" . $config->{url} . "/" . $config->{imgs_dir} . $IMGz[$e * 10 + 3] . "\"><img src='" . $config->{url} . "/" . $config->{imgs_dir} . $IMG[$e * 10 + 3] . "' border='0'></a>\n");
+					push(@output, "      " . picz_a_element(config => $config, IMGz => $IMGz[$e * 10 + 3], IMG => $IMG[$e * 10 + 3]) . "\n");
 				} else {
 					if($version eq "new") {
 						$picz_width = $picz->{image_width} * $config->{global_zoom};
@@ -995,10 +1021,10 @@ sub process_cgi {
 						$picz_width = $width + 115;
 						$picz_height = $height + 100;
 					}
-					push(@output, "      <a href=\"javascript:void(window.open('" . $config->{url} . "/" . $config->{imgs_dir} . $IMGz[$e * 10 + 3] . "','','width=" . $picz_width . ",height=" . $picz_height . ",scrollbars=0,resizable=0'))\"><img src='" . $config->{url} . "/" . $config->{imgs_dir} . $IMG[$e * 10 + 3] . "' border='0'></a>\n");
+					push(@output, "      " . picz_js_a_element(width => $picz_width, height => $picz_height, config => $config, IMGz => $IMGz[$e * 10 + 3], IMG => $IMG[$e * 10 + 3]) . "\n");
 				}
 			} else {
-				push(@output, "      <img src='" . $config->{url} . "/" . $config->{imgs_dir} . $IMG[$e * 10 + 3] . "'>\n");
+				push(@output, "      " . img_element(config => $config, IMG => $IMG[$e * 10 + 3]) . "\n");
 			}
 		}
 
@@ -1071,6 +1097,7 @@ sub process_cgi {
 				"--vertical-label=Files",
 				"--width=$width",
 				"--height=$height",
+				@full_size_mode,
 				@extra,
 				@riglim,
 				$zoom,
@@ -1096,7 +1123,7 @@ sub process_cgi {
 		if($title || ($silent =~ /imagetag/ && $graph =~ /process$e2/)) {
 			if(lc($config->{enable_zoom}) eq "y") {
 				if(lc($config->{disable_javascript_void}) eq "y") {
-					push(@output, "      <a href=\"" . $config->{url} . "/" . $config->{imgs_dir} . $IMGz[$e * 10 + 4] . "\"><img src='" . $config->{url} . "/" . $config->{imgs_dir} . $IMG[$e * 10 + 4] . "' border='0'></a>\n");
+					push(@output, "      " . picz_a_element(config => $config, IMGz => $IMGz[$e * 10 + 4], IMG => $IMG[$e * 10 + 4]) . "\n");
 				} else {
 					if($version eq "new") {
 						$picz_width = $picz->{image_width} * $config->{global_zoom};
@@ -1105,10 +1132,10 @@ sub process_cgi {
 						$picz_width = $width + 115;
 						$picz_height = $height + 100;
 					}
-					push(@output, "      <a href=\"javascript:void(window.open('" . $config->{url} . "/" . $config->{imgs_dir} . $IMGz[$e * 10 + 4] . "','','width=" . $picz_width . ",height=" . $picz_height . ",scrollbars=0,resizable=0'))\"><img src='" . $config->{url} . "/" . $config->{imgs_dir} . $IMG[$e * 10 + 4] . "' border='0'></a>\n");
+					push(@output, "      " . picz_js_a_element(width => $picz_width, height => $picz_height, config => $config, IMGz => $IMGz[$e * 10 + 4], IMG => $IMG[$e * 10 + 4]) . "\n");
 				}
 			} else {
-				push(@output, "      <img src='" . $config->{url} . "/" . $config->{imgs_dir} . $IMG[$e * 10 + 4] . "'>\n");
+				push(@output, "      " . img_element(config => $config, IMG => $IMG[$e * 10 + 4]) . "\n");
 			}
 		}
 
@@ -1184,6 +1211,7 @@ sub process_cgi {
 				"--vertical-label=Threads",
 				"--width=$width",
 				"--height=$height",
+				@full_size_mode,
 				@extra,
 				@riglim,
 				$zoom,
@@ -1209,7 +1237,7 @@ sub process_cgi {
 		if($title || ($silent =~ /imagetag/ && $graph =~ /process$e2/)) {
 			if(lc($config->{enable_zoom}) eq "y") {
 				if(lc($config->{disable_javascript_void}) eq "y") {
-					push(@output, "      <a href=\"" . $config->{url} . "/" . $config->{imgs_dir} . $IMGz[$e * 10 + 5] . "\"><img src='" . $config->{url} . "/" . $config->{imgs_dir} . $IMG[$e * 10 + 5] . "' border='0'></a>\n");
+					push(@output, "      " . picz_a_element(config => $config, IMGz => $IMGz[$e * 10 + 5], IMG => $IMG[$e * 10 + 5]) . "\n");
 				} else {
 					if($version eq "new") {
 						$picz_width = $picz->{image_width} * $config->{global_zoom};
@@ -1218,10 +1246,10 @@ sub process_cgi {
 						$picz_width = $width + 115;
 						$picz_height = $height + 100;
 					}
-					push(@output, "      <a href=\"javascript:void(window.open('" . $config->{url} . "/" . $config->{imgs_dir} . $IMGz[$e * 10 + 5] . "','','width=" . $picz_width . ",height=" . $picz_height . ",scrollbars=0,resizable=0'))\"><img src='" . $config->{url} . "/" . $config->{imgs_dir} . $IMG[$e * 10 + 5] . "' border='0'></a>\n");
+					push(@output, "      " . picz_js_a_element(width => $picz_width, height => $picz_height, config => $config, IMGz => $IMGz[$e * 10 + 5], IMG => $IMG[$e * 10 + 5]) . "\n");
 				}
 			} else {
-				push(@output, "      <img src='" . $config->{url} . "/" . $config->{imgs_dir} . $IMG[$e * 10 + 5] . "'>\n");
+				push(@output, "      " . img_element(config => $config, IMG => $IMG[$e * 10 + 5]) . "\n");
 			}
 		}
 
@@ -1330,6 +1358,7 @@ sub process_cgi {
 				"--vertical-label=Nonvoluntary + voluntary/s",
 				"--width=$width",
 				"--height=$height",
+				@full_size_mode,
 				@extra,
 				@riglim,
 				$zoom,
@@ -1386,7 +1415,7 @@ sub process_cgi {
 		if($title || ($silent =~ /imagetag/ && $graph =~ /process$e2/)) {
 			if(lc($config->{enable_zoom}) eq "y") {
 				if(lc($config->{disable_javascript_void}) eq "y") {
-					push(@output, "      <a href=\"" . $config->{url} . "/" . $config->{imgs_dir} . $IMGz[$e * 10 + 6] . "\"><img src='" . $config->{url} . "/" . $config->{imgs_dir} . $IMG[$e * 10 + 6] . "' border='0'></a>\n");
+					push(@output, "      " . picz_a_element(config => $config, IMGz => $IMGz[$e * 10 + 6], IMG => $IMG[$e * 10 + 6]) . "\n");
 				} else {
 					if($version eq "new") {
 						$picz_width = $picz->{image_width} * $config->{global_zoom};
@@ -1395,10 +1424,10 @@ sub process_cgi {
 						$picz_width = $width + 115;
 						$picz_height = $height + 100;
 					}
-					push(@output, "      <a href=\"javascript:void(window.open('" . $config->{url} . "/" . $config->{imgs_dir} . $IMGz[$e * 10 + 6] . "','','width=" . $picz_width . ",height=" . $picz_height . ",scrollbars=0,resizable=0'))\"><img src='" . $config->{url} . "/" . $config->{imgs_dir} . $IMG[$e * 10 + 6] . "' border='0'></a>\n");
+					push(@output, "      " . picz_js_a_element(width => $picz_width, height => $picz_height, config => $config, IMGz => $IMGz[$e * 10 + 6], IMG => $IMG[$e * 10 + 6]) . "\n");
 				}
 			} else {
-				push(@output, "      <img src='" . $config->{url} . "/" . $config->{imgs_dir} . $IMG[$e * 10 + 6] . "'>\n");
+				push(@output, "      " . img_element(config => $config, IMG => $IMG[$e * 10 + 6]) . "\n");
 			}
 		}
 
@@ -1474,6 +1503,7 @@ sub process_cgi {
 				"--vertical-label=Processes",
 				"--width=$width",
 				"--height=$height",
+				@full_size_mode,
 				@extra,
 				@riglim,
 				$zoom,
@@ -1499,7 +1529,7 @@ sub process_cgi {
 		if($title || ($silent =~ /imagetag/ && $graph =~ /process$e2/)) {
 			if(lc($config->{enable_zoom}) eq "y") {
 				if(lc($config->{disable_javascript_void}) eq "y") {
-					push(@output, "      <a href=\"" . $config->{url} . "/" . $config->{imgs_dir} . $IMGz[$e * 10 + 7] . "\"><img src='" . $config->{url} . "/" . $config->{imgs_dir} . $IMG[$e * 10 + 7] . "' border='0'></a>\n");
+					push(@output, "      " . picz_a_element(config => $config, IMGz => $IMGz[$e * 10 + 7], IMG => $IMG[$e * 10 + 7]) . "\n");
 				} else {
 					if($version eq "new") {
 						$picz_width = $picz->{image_width} * $config->{global_zoom};
@@ -1508,13 +1538,274 @@ sub process_cgi {
 						$picz_width = $width + 115;
 						$picz_height = $height + 100;
 					}
-					push(@output, "      <a href=\"javascript:void(window.open('" . $config->{url} . "/" . $config->{imgs_dir} . $IMGz[$e * 10 + 7] . "','','width=" . $picz_width . ",height=" . $picz_height . ",scrollbars=0,resizable=0'))\"><img src='" . $config->{url} . "/" . $config->{imgs_dir} . $IMG[$e * 10 + 7] . "' border='0'></a>\n");
+					push(@output, "      " . picz_js_a_element(width => $picz_width, height => $picz_height, config => $config, IMGz => $IMGz[$e * 10 + 7], IMG => $IMG[$e * 10 + 7]) . "\n");
 				}
 			} else {
-				push(@output, "      <img src='" . $config->{url} . "/" . $config->{imgs_dir} . $IMG[$e * 10 + 7] . "'>\n");
+				push(@output, "      " . img_element(config => $config, IMG => $IMG[$e * 10 + 7]) . "\n");
 			}
 		}
 
+		@riglim = @{setup_riglim($rigid[8], $limit[8])};
+		undef(@tmp);
+		undef(@tmpz);
+		undef(@CDEF);
+		my $ytitle;
+		my $unit;
+		my $format;
+		if(lc(($process->{time_unit} || "") eq "minute")) {
+			$ytitle = "Minutes";
+			$unit = 60;
+			$format = "%5.0lf";
+		} elsif(lc(($process->{time_unit} || "") eq "hour")) {
+			$ytitle = "Hours";
+			$unit = 3600;
+			$format = "%4.0lf";
+		} else {
+			$ytitle = "Days";
+			$unit = 86400;
+			$format = "%4.1lf";
+		}
+		for($n = 0; $n < 10; $n++) {
+			my $p = trim($lp[$n] || "");
+
+			if($p) {
+				$str = trim((split(',', $process->{desc}->{$p} || ""))[0]) || $p;
+				$str =~ s/:/\\:/g;	# escape colons
+				push(@tmpz, "LINE2:uptd" . $n . $LC[$n] . ":$str");
+				$str = sprintf("%-20s", substr($str, 0, 20));
+				push(@tmp, "LINE2:uptd" . $n . $LC[$n] . ":$str");
+				push(@tmp, "GPRINT:uptd" . $n . ":LAST:Cur\\: $format");
+				push(@tmp, "GPRINT:uptd" . $n . ":MIN:  Min\\: $format");
+				push(@tmp, "GPRINT:uptd" . $n . ":MAX:  Max\\: $format\\n");
+			}
+		}
+		if($title) {
+			push(@output, "    <tr>\n");
+			push(@output, "    <td>\n");
+		}
+		if(lc($config->{show_gaps}) eq "y") {
+			push(@tmp, "AREA:wrongdata#$colors->{gap}:");
+			push(@tmpz, "AREA:wrongdata#$colors->{gap}:");
+			push(@CDEF, "CDEF:wrongdata=allvalues,UN,INF,UNKN,IF");
+		}
+		($width, $height) = split('x', $config->{graph_size}->{medium});
+		if($silent =~ /imagetag/) {
+			($width, $height) = split('x', $config->{graph_size}->{remote}) if $silent eq "imagetag";
+			($width, $height) = split('x', $config->{graph_size}->{main}) if $silent eq "imagetagbig";
+			@tmp = @tmpz;
+		}
+		$pic = $rrd{$version}->("$IMG_DIR" . "$IMG[$e * 10 + 8]",
+			"--title=$config->{graphs}->{_process9}  ($tf->{nwhen}$tf->{twhen})",
+			"--start=-$tf->{nwhen}$tf->{twhen}",
+			"--imgformat=$imgfmt_uc",
+			"--vertical-label=$ytitle",
+			"--width=$width",
+			"--height=$height",
+			@extra,
+			@riglim,
+			$zoom,
+			@{$cgi->{version12}},
+			@{$colors->{graph_colors}},
+			"DEF:upt0=$rrd:proc" . $e . "_upt0:AVERAGE",
+			"DEF:upt1=$rrd:proc" . $e . "_upt1:AVERAGE",
+			"DEF:upt2=$rrd:proc" . $e . "_upt2:AVERAGE",
+			"DEF:upt3=$rrd:proc" . $e . "_upt3:AVERAGE",
+			"DEF:upt4=$rrd:proc" . $e . "_upt4:AVERAGE",
+			"DEF:upt5=$rrd:proc" . $e . "_upt5:AVERAGE",
+			"DEF:upt6=$rrd:proc" . $e . "_upt6:AVERAGE",
+			"DEF:upt7=$rrd:proc" . $e . "_upt7:AVERAGE",
+			"DEF:upt8=$rrd:proc" . $e . "_upt8:AVERAGE",
+			"DEF:upt9=$rrd:proc" . $e . "_upt9:AVERAGE",
+			"CDEF:uptd0=upt0,$unit,/",
+			"CDEF:uptd1=upt1,$unit,/",
+			"CDEF:uptd2=upt2,$unit,/",
+			"CDEF:uptd3=upt3,$unit,/",
+			"CDEF:uptd4=upt4,$unit,/",
+			"CDEF:uptd5=upt5,$unit,/",
+			"CDEF:uptd6=upt6,$unit,/",
+			"CDEF:uptd7=upt7,$unit,/",
+			"CDEF:uptd8=upt8,$unit,/",
+			"CDEF:uptd9=upt9,$unit,/",
+			"CDEF:allvalues=uptd0,uptd1,uptd2,uptd3,uptd4,uptd5,uptd6,uptd7,uptd8,uptd9,+,+,+,+,+,+,+,+,+",
+			@CDEF,
+			@tmp);
+		$err = RRDs::error;
+		push(@output, "ERROR: while graphing $IMG_DIR" . "$IMG[$e * 10 + 8]: $err\n") if $err;
+		if(lc($config->{enable_zoom}) eq "y") {
+			($width, $height) = split('x', $config->{graph_size}->{zoom});
+			$picz = $rrd{$version}->("$IMG_DIR" . "$IMGz[$e * 10 + 8]",
+				"--title=$config->{graphs}->{_process9}  ($tf->{nwhen}$tf->{twhen})",
+				"--start=-$tf->{nwhen}$tf->{twhen}",
+				"--imgformat=$imgfmt_uc",
+				"--vertical-label=$ytitle",
+				"--width=$width",
+				"--height=$height",
+				@full_size_mode,
+				@extra,
+				@riglim,
+				$zoom,
+				@{$cgi->{version12}},
+				@{$colors->{graph_colors}},
+				"DEF:upt0=$rrd:proc" . $e . "_upt0:AVERAGE",
+				"DEF:upt1=$rrd:proc" . $e . "_upt1:AVERAGE",
+				"DEF:upt2=$rrd:proc" . $e . "_upt2:AVERAGE",
+				"DEF:upt3=$rrd:proc" . $e . "_upt3:AVERAGE",
+				"DEF:upt4=$rrd:proc" . $e . "_upt4:AVERAGE",
+				"DEF:upt5=$rrd:proc" . $e . "_upt5:AVERAGE",
+				"DEF:upt6=$rrd:proc" . $e . "_upt6:AVERAGE",
+				"DEF:upt7=$rrd:proc" . $e . "_upt7:AVERAGE",
+				"DEF:upt8=$rrd:proc" . $e . "_upt8:AVERAGE",
+				"DEF:upt9=$rrd:proc" . $e . "_upt9:AVERAGE",
+				"CDEF:uptd0=upt0,$unit,/",
+				"CDEF:uptd1=upt1,$unit,/",
+				"CDEF:uptd2=upt2,$unit,/",
+				"CDEF:uptd3=upt3,$unit,/",
+				"CDEF:uptd4=upt4,$unit,/",
+				"CDEF:uptd5=upt5,$unit,/",
+				"CDEF:uptd6=upt6,$unit,/",
+				"CDEF:uptd7=upt7,$unit,/",
+				"CDEF:uptd8=upt8,$unit,/",
+				"CDEF:uptd9=upt9,$unit,/",
+				"CDEF:allvalues=uptd0,uptd1,uptd2,uptd3,uptd4,uptd5,uptd6,uptd7,uptd8,uptd9,+,+,+,+,+,+,+,+,+",
+				@CDEF,
+				@tmpz);
+			$err = RRDs::error;
+			push(@output, "ERROR: while graphing $IMG_DIR" . "$IMGz[$e * 10 + 8]: $err\n") if $err;
+		}
+		$e2 = $e . "8";
+		if($title || ($silent =~ /imagetag/ && $graph =~ /process$e2/)) {
+			if(lc($config->{enable_zoom}) eq "y") {
+				if(lc($config->{disable_javascript_void}) eq "y") {
+					push(@output, "      " . picz_a_element(config => $config, IMGz => $IMGz[$e * 10 + 8], IMG => $IMG[$e * 10 + 8]) . "\n");
+				} else {
+					if($version eq "new") {
+						$picz_width = $picz->{image_width} * $config->{global_zoom};
+						$picz_height = $picz->{image_height} * $config->{global_zoom};
+					} else {
+						$picz_width = $width + 115;
+						$picz_height = $height + 100;
+					}
+					push(@output, "      " . picz_js_a_element(width => $picz_width, height => $picz_height, config => $config, IMGz => $IMGz[$e * 10 + 8], IMG => $IMG[$e * 10 + 8]) . "\n");
+				}
+			} else {
+				push(@output, "      " . img_element(config => $config, IMG => $IMG[$e * 10 + 8]) . "\n");
+			}
+		}
+
+		if($title) {
+			push(@output, "    </td>\n");
+			push(@output, "    <td class='td-valign-top'>\n");
+		}
+#		@riglim = @{setup_riglim($rigid[9], $limit[9])};
+#		undef(@tmp);
+#		undef(@tmpz);
+#		undef(@CDEF);
+#		for($n = 0; $n < 10; $n++) {
+#			my $p = trim($lp[$n] || "");
+#
+#			if($p) {
+#				$str = trim((split(',', $process->{desc}->{$p} || ""))[0]) || $p;
+#				$str =~ s/:/\\:/g;	# escape colons
+#				push(@tmpz, "LINE2:xxx" . $n . $LC[$n] . ":$str");
+#				$str = sprintf("%-20s", substr($str, 0, 20));
+#				push(@tmp, "LINE2:xxx" . $n . $LC[$n] . ":$str");
+#				push(@tmp, "GPRINT:xxx" . $n . ":LAST:Cur\\: %4.0lf");
+#				push(@tmp, "GPRINT:xxx" . $n . ":MIN:  Min\\: %4.0lf");
+#				push(@tmp, "GPRINT:xxx" . $n . ":MAX:  Max\\: %4.0lf\\n");
+#			}
+#		}
+#		if(lc($config->{show_gaps}) eq "y") {
+#			push(@tmp, "AREA:wrongdata#$colors->{gap}:");
+#			push(@tmpz, "AREA:wrongdata#$colors->{gap}:");
+#			push(@CDEF, "CDEF:wrongdata=allvalues,UN,INF,UNKN,IF");
+#		}
+#		($width, $height) = split('x', $config->{graph_size}->{medium});
+#		if($silent =~ /imagetag/) {
+#			($width, $height) = split('x', $config->{graph_size}->{remote}) if $silent eq "imagetag";
+#			($width, $height) = split('x', $config->{graph_size}->{main}) if $silent eq "imagetagbig";
+#			@tmp = @tmpz;
+#			push(@tmp, "COMMENT: \\n");
+#			push(@tmp, "COMMENT: \\n");
+#			push(@tmp, "COMMENT: \\n");
+#		}
+#		$pic = $rrd{$version}->("$IMG_DIR" . "$IMG[$e * 10 + 9]",
+#			"--title=$config->{graphs}->{_process10}  ($tf->{nwhen}$tf->{twhen})",
+#			"--start=-$tf->{nwhen}$tf->{twhen}",
+#			"--imgformat=$imgfmt_uc",
+#			"--vertical-label=Xxxxxxxxx",
+#			"--width=$width",
+#			"--height=$height",
+#			@extra,
+#			@riglim,
+#			$zoom,
+#			@{$cgi->{version12}},
+#			@{$colors->{graph_colors}},
+#			"DEF:xxx0=$rrd:proc" . $e . "_xxx0:AVERAGE",
+#			"DEF:xxx1=$rrd:proc" . $e . "_xxx1:AVERAGE",
+#			"DEF:xxx2=$rrd:proc" . $e . "_xxx2:AVERAGE",
+#			"DEF:xxx3=$rrd:proc" . $e . "_xxx3:AVERAGE",
+#			"DEF:xxx4=$rrd:proc" . $e . "_xxx4:AVERAGE",
+#			"DEF:xxx5=$rrd:proc" . $e . "_xxx5:AVERAGE",
+#			"DEF:xxx6=$rrd:proc" . $e . "_xxx6:AVERAGE",
+#			"DEF:xxx7=$rrd:proc" . $e . "_xxx7:AVERAGE",
+#			"DEF:xxx8=$rrd:proc" . $e . "_xxx8:AVERAGE",
+#			"DEF:xxx9=$rrd:proc" . $e . "_xxx9:AVERAGE",
+#			"CDEF:allvalues=xxx0,xxx1,xxx2,xxx3,xxx4,xxx5,xxx6,xxx7,xxx8,xxx9,+,+,+,+,+,+,+,+,+",
+#			@CDEF,
+#			@tmp);
+#		$err = RRDs::error;
+#		push(@output, "ERROR: while graphing $IMG_DIR" . "$IMG[$e * 10 + 9]: $err\n") if $err;
+#		if(lc($config->{enable_zoom}) eq "y") {
+#			($width, $height) = split('x', $config->{graph_size}->{zoom});
+#			$picz = $rrd{$version}->("$IMG_DIR" . "$IMGz[$e * 10 + 9]",
+#				"--title=$config->{graphs}->{_process10}  ($tf->{nwhen}$tf->{twhen})",
+#				"--start=-$tf->{nwhen}$tf->{twhen}",
+#				"--imgformat=$imgfmt_uc",
+#				"--vertical-label=Xxxxxxxxx",
+#				"--width=$width",
+#				"--height=$height",
+#				@full_size_mode,
+#				@extra,
+#				@riglim,
+#				$zoom,
+#				@{$cgi->{version12}},
+#				@{$colors->{graph_colors}},
+#				"DEF:xxx0=$rrd:proc" . $e . "_xxx0:AVERAGE",
+#				"DEF:xxx1=$rrd:proc" . $e . "_xxx1:AVERAGE",
+#				"DEF:xxx2=$rrd:proc" . $e . "_xxx2:AVERAGE",
+#				"DEF:xxx3=$rrd:proc" . $e . "_xxx3:AVERAGE",
+#				"DEF:xxx4=$rrd:proc" . $e . "_xxx4:AVERAGE",
+#				"DEF:xxx5=$rrd:proc" . $e . "_xxx5:AVERAGE",
+#				"DEF:xxx6=$rrd:proc" . $e . "_xxx6:AVERAGE",
+#				"DEF:xxx7=$rrd:proc" . $e . "_xxx7:AVERAGE",
+#				"DEF:xxx8=$rrd:proc" . $e . "_xxx8:AVERAGE",
+#				"DEF:xxx9=$rrd:proc" . $e . "_xxx9:AVERAGE",
+#				"CDEF:allvalues=xxx0,xxx1,xxx2,xxx3,xxx4,xxx5,xxx6,xxx7,xxx8,xxx9,+,+,+,+,+,+,+,+,+",
+#				@CDEF,
+#				@tmpz);
+#			$err = RRDs::error;
+#			push(@output, "ERROR: while graphing $IMG_DIR" . "$IMGz[$e * 10 + 9]: $err\n") if $err;
+#		}
+#		$e2 = $e . "9";
+#		if($title || ($silent =~ /imagetag/ && $graph =~ /process$e2/)) {
+#			if(lc($config->{enable_zoom}) eq "y") {
+#				if(lc($config->{disable_javascript_void}) eq "y") {
+#					push(@output, "      " . picz_a_element(config => $config, IMGz => $IMGz[$e * 10 + 9], IMG => $IMG[$e * 10 + 9]) . "\n");
+#				} else {
+#					if($version eq "new") {
+#						$picz_width = $picz->{image_width} * $config->{global_zoom};
+#						$picz_height = $picz->{image_height} * $config->{global_zoom};
+#					} else {
+#						$picz_width = $width + 115;
+#						$picz_height = $height + 100;
+#					}
+#					push(@output, "      " . picz_js_a_element(width => $picz_width, height => $picz_height, config => $config, IMGz => $IMGz[$e * 10 + 9], IMG => $IMG[$e * 10 + 9]) . "\n");
+#				}
+#			} else {
+#				push(@output, "      " . img_element(config => $config, IMG => $IMG[$e * 10 + 9]) . "\n");
+#			}
+#		}
+
 		if($title) {
 			push(@output, "    </td>\n");
 			push(@output, "    </tr>\n");
